Utilities
=========

Misc. Utilities
---------------

This documents general purpose utility functions available in Logbook.

.. currentmodule:: logbook

.. autofunction:: debug

.. autofunction:: info

.. autofunction:: warn

.. autofunction:: warning

.. autofunction:: notice

.. autofunction:: error

.. autofunction:: exception

.. autofunction:: catch_exceptions

.. autofunction:: critical

.. autofunction:: log

.. autofunction:: set_datetime_format

Slow Operations Logging
-----------------------

.. currentmodule:: logbook.utils
.. autofunction:: logged_if_slow


Deprecations
------------

.. autofunction:: deprecated

.. autofunction:: suppressed_deprecations
